@@ -4,13 +4,17 @@ kombu.transport.pypika
 
 Pika transport.
 
-:copyright: (c) 2009 - 2010 by Ask Solem.
+:copyright: (c) 2009 - 2011 by Ask Solem.
 :license: BSD, see LICENSE for more details.
 
 """
 import socket
 
-from pika import asyncore_adapter
+import pika
+try:
+    from pika import asyncore_adapter
+except ImportError:
+    raise ImportError("Kombu only works with pika version 0.5.2")
 from pika import blocking_adapter
 from pika import channel
 from pika import connection
@@ -25,12 +29,13 @@ DEFAULT_PORT = 5672
 class Message(base.Message):
 
     def __init__(self, channel, amqp_message, **kwargs):
-        channel_id, method, header, body = amqp_message
+        channel_id, method, props, body = amqp_message
 
         kwargs.update({"body": body,
                        "delivery_tag": method.delivery_tag,
-                       "content_type": header.content_type,
-                       "content_encoding": header.content_encoding,
+                       "content_type": props.content_type,
+                       "content_encoding": props.content_encoding,
+                       "headers": props.headers,
                        "delivery_info": dict(
                             consumer_tag=getattr(method, "consumer_tag", None),
                             routing_key=method.routing_key,
@@ -110,7 +115,9 @@ class Channel(channel.Channel):
 class BlockingConnection(blocking_adapter.BlockingConnection):
 
     def channel(self):
-        return Channel(channel.ChannelHandler(self))
+        c = Channel(channel.ChannelHandler(self))
+        c.connection = self
+        return c
 
     def ensure_drain_events(self, timeout=None):
         return self.drain_events(timeout=timeout)
@@ -121,7 +128,9 @@ class AsyncoreConnection(asyncore_adapter.AsyncoreConnection):
     Super = asyncore_adapter.AsyncoreConnection
 
     def channel(self):
-        return Channel(channel.ChannelHandler(self))
+        c = Channel(channel.ChannelHandler(self))
+        c.connection = self
+        return c
 
     def ensure_drain_events(self, timeout=None):
         # asyncore connection does not raise socket.timeout when timing out
@@ -129,7 +138,7 @@ class AsyncoreConnection(asyncore_adapter.AsyncoreConnection):
         # of sync connection.
         current_events = self._event_counter
         self.drain_events(timeout=timeout)
-        if self._event_counter <= current_events:
+        if timeout and self._event_counter <= current_events:
             raise socket.timeout("timed out")
 
     def on_data_available(self, buf):
