@@ -100,7 +100,8 @@ class MultiChannelPoller(object):
         for fileno, event in events:
             if event & eventio.POLL_READ:
                 chan, type = self._fd_to_chan[fileno]
-                return chan.handlers[type](), self
+                if chan.qos.can_consume():
+                    return chan.handlers[type](), self
             elif event & eventio.POLL_HUP:
                 chan, type = self._fd_to_chan[fileno]
                 chan._poll_error(type)
@@ -127,6 +128,10 @@ class Channel(virtual.Channel):
         self.active_fanout_queues = set()
         self._fanout_to_queue = {}
         self.handlers = {"BRPOP": self._brpop_read, "LISTEN": self._receive}
+
+        # Evaluate connection.
+        self.client.info()
+
         self.connection.cycle.add(self)  # add to channel poller.
 
     def basic_consume(self, queue, *args, **kwargs):
